
***************************
* File: budget_etat.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\Second Round\SSD\budget_etat.dta"


**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\SSD"
log using "budget_etat", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "budget_etat label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************

egen  fivondronana_code=group( fivondronana)
label var  fivondronana_code " fivondronana code"
order  fivondronana  fivondronana_code

local mylist "  mont_initial mont_modif mont_enga mont_fonct mont_csb mont_nondis taxe"
levelsof   article, local(  article_levels)
foreach v of varlist   mont_initial mont_modif mont_enga mont_fonct mont_csb mont_nondis taxe{
local l`v' : variable label `v'
}
reshape wide  mont_initial mont_modif mont_enga mont_fonct mont_csb mont_nondis taxe, i( fivondronana_code) j( article)
foreach x of local mylist{
foreach y of local   article_levels{
label var `x'`y' "`l`x''"
}
}


**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

**************************************************
***    Identify outliers
**************************************************

mvdecode _all, mv(0 = .z)
grubbs  mont_initial* mont_modif* mont_enga* mont_fonct* mont_csb* mont_nondis*, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)


**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\SSD"
log using "budget_etat codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\SSD"
save budget_etat_cleaned_data.dta, replace
