
***************************
* File: commune_rupture_stock.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off

use "Source\4- Data\4.1 Raw Data\Second Round\SSD\entete_ssd.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\SSD"
log using "entete_ssd", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "entete_ssd label values", replace

**************************************************
***   Unique identifiers: ID
**************************************************
egen fivondronana_code=group(fivondronana)
label var fivondronana_code "fivondronana code"
order  fivondronana fivondronana_code


**************************************************
***   Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 


**************************************************
***    Identify illegal responses
**************************************************

log using "entete_ssd label inspect", replace
inspect
log close


**************************************************
***    Identify outliers
**************************************************
mvdecode _all, mv(0 = .z)
grubbs   q2_fs1 q2_fs2 q2_fs3 q2_fs4 q2_fs5 q2_fs6 q2_autfs, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)


**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\SSD"
log using "entete_ssd codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P H\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\SSD"
save entete_ssd_cleaned_data.dta, replace
