
***************************
* File: mobilisations_sociales.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\Second Round\SSD\mobilisations_sociales.dta"


**************************************************
***  Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\SSD"
log using "mobilisations_sociales", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "mobilisations_sociales label values", replace

**************************************************
***   Unique identifiers: ID
**************************************************
egen fivondronana_code=group(fivondronana)
label var fivondronana_code "fivondronana code"
order  fivondronana fivondronana_code


drop  type_mobil
sort  fivondronana_code num_mobil
drop in 231
local mylist "  nb_fs1 nb_fs2 nb_fs3 nb_fs4 nb_fs5 nb_fs6 nb_aut_fs"
levelsof   num_mobil, local(  num_mobil_levels)
foreach v of varlist   nb_fs1 nb_fs2 nb_fs3 nb_fs4 nb_fs5 nb_fs6 nb_aut_fs{
local l`v' : variable label `v'
}
reshape wide  nb_fs1 nb_fs2 nb_fs3 nb_fs4 nb_fs5 nb_fs6 nb_aut_fs, i(fivondronana_code) j(  num_mobil)
foreach x of local mylist{
foreach y of local   num_mobil_levels{
label var `x'`y' "`l`x''"
}
}



**************************************************
***   Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

**************************************************
***    Identify illegal responses
**************************************************

log using "mobilisations_sociales label inspect", replace
inspect
log close

**************************************************
***    Identify outliers
**************************************************
mvdecode _all, mv(0 = .z)
grubbs   nb_fs1* nb_fs2* nb_fs3* nb_fs4* nb_fs5* nb_fs6* nb_aut_fs*, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)


**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\SSD"
log using "mobilisations_sociales codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\SSD"
save mobilisations_sociales_cleaned_data.dta, replace
