
***************************
* File: q3_equipements.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\Second Round\SSD\q3_equipements.dta"


**************************************************
***    Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\SSD"
log using "q3_equipements", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "q3_equipements label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen fivondronana_code=group(fivondronana)
label var fivondronana_code "fivondronana code"
order  fivondronana fivondronana_code


drop  type_eqpt
local mylist "  qte_achat unit_achat val_achat qte_rec_eta unit_etat qte_rec_part unit_part typ_part mod_part qte_dist unit_dist"
levelsof   num_eqpt, local(  num_eqpt_levels)
foreach v of varlist  qte_achat unit_achat val_achat qte_rec_eta unit_etat qte_rec_part unit_part typ_part mod_part qte_dist unit_dist{
local l`v' : variable label `v'
}
reshape wide   qte_achat unit_achat val_achat qte_rec_eta unit_etat qte_rec_part unit_part typ_part mod_part qte_dist unit_dist, i(fivondronana_code) j(  num_eqpt)
foreach x of local mylist{
foreach y of local   num_eqpt_levels{
label var `x'`y' "`l`x''"
}
}


**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 


**************************************************
***    Identify illegal responses
**************************************************

log using "q3_equipements label inspect", replace
inspect
log close

**************************************************
***    Identify outliers
**************************************************
mvdecode _all, mv(0 = .z)
grubbs  qte_achat* unit_achat* val_achat* qte_rec_eta* unit_etat* qte_rec_part* unit_part* typ_part*  qte_dist* unit_dist*, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\SSD"
log using "q3_equipements codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\SSD"
save q3_equipements_cleaned_data.dta, replace
