
***************************
* File: q4_qte_distribuee.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\Second Round\SSD\q4_qte_distribuee.dta"


**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\SSD"
log using "q4_qte_distribuee", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "q4_qte_distribuee label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen fivondronana_code=group(fivondronana)
label var fivondronana_code "fivondronana code"
order  fivondronana fivondronana_code


drop  type_eqpt
local mylist " qte_fs1 qte_fs2 qte_fs3 qte_fs4 qte_fs5 qte_fs6 qte_aut_fs"
levelsof   num_eqpt, local(  num_eqpt_levels)
foreach v of varlist   qte_fs1 qte_fs2 qte_fs3 qte_fs4 qte_fs5 qte_fs6 qte_aut_fs{
local l`v' : variable label `v'
}
reshape wide   qte_fs1 qte_fs2 qte_fs3 qte_fs4 qte_fs5 qte_fs6 qte_aut_fs, i(fivondronana_code) j(  num_eqpt)
foreach x of local mylist{
foreach y of local   num_eqpt_levels{
label var `x'`y' "`l`x''"
}
}


**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

**************************************************
***    Identify illegal responses
**************************************************

log using "q4_qte_distribuee label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
mvdecode _all, mv(0 = .z)
grubbs  qte_fs1* qte_fs2* qte_fs3* qte_fs4* qte_fs5* qte_fs6* qte_aut_fs*, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\SSD"
log using "q4_qte_distribuee codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\SSD"
save q4_qte_distribuee_cleaned_data.dta, replace
